@@ -4,7 +4,7 @@ use v5.14;
 use warnings;
 use utf8;
 
-our $VERSION = "2.13";
+our $VERSION = "2.1301";
 
 use Data::Dumper;
 $Data::Dumper::Sortkeys = 1;
@@ -358,7 +358,7 @@ sub fold {
     }
 
     if ($word_char_re
-	and my $tail = (/\A(${word_char_re}+)/)[0]
+	and my($tail) = /\A(${word_char_re}+)/
 	and $folded =~ m{
 		^
 		( (?: [^\e]* ${csi_re}++ ) *+ )
@@ -523,7 +523,7 @@ Text::ANSI::Fold - Text folding library supporting ANSI terminal sequence and As
 
 =head1 VERSION
 
-Version 2.13
+Version 2.1301
 
 =head1 SYNOPSIS
 
